[sword-svn] r3049 - trunk/cmake

chrislit at crosswire.org chrislit at crosswire.org
Sun Mar 2 04:47:47 MST 2014


Author: chrislit
Date: 2014-03-02 04:47:47 -0700 (Sun, 02 Mar 2014)
New Revision: 3049

Modified:
   trunk/cmake/FindBZIP2.cmake
   trunk/cmake/FindXZ.cmake
Log:
CMake project fixes for bzip2/xv


Modified: trunk/cmake/FindBZIP2.cmake
===================================================================
--- trunk/cmake/FindXZ.cmake	2014-03-02 10:29:21 UTC (rev 3048)
+++ trunk/cmake/FindXZ.cmake	2014-03-02 11:47:47 UTC (rev 3049)
@@ -3,7 +3,7 @@
 #
 #  XZ_FOUND - system has XZ
 #  XZ_INCLUDE_DIR - the XZ include directory
-#  XZ_LIBRARIES - Link these to use XZ
+#  XZ_LIBRARY - Link these to use XZ
 #  XZ_DEFINITIONS - Compiler switches required for using XZ
 
 # Copyright (c) 2006, Alexander Neundorf, <neundorf at kde.org>
@@ -12,17 +12,17 @@
 # For details see the accompanying COPYING-CMAKE-SCRIPTS file.
 
 
-IF (XZ_INCLUDE_DIR AND XZ_LIBRARIES)
+IF (XZ_INCLUDE_DIR AND XZ_LIBRARY)
     SET(XZ_FIND_QUIETLY TRUE)
-ENDIF (XZ_INCLUDE_DIR AND XZ_LIBRARIES)
+ENDIF (XZ_INCLUDE_DIR AND XZ_LIBRARY)
 
 FIND_PATH(XZ_INCLUDE_DIR lzma.h )
 
-FIND_LIBRARY(XZ_LIBRARY NAMES lzma )
+FIND_LIBRARY(XZ_LIBRARY lzma )
 
 # handle the QUIETLY and REQUIRED arguments and set XZ_FOUND to TRUE if 
 # all listed variables are TRUE
 INCLUDE(FindPackageHandleStandardArgs)
-FIND_PACKAGE_HANDLE_STANDARD_ARGS(XZ DEFAULT_MSG XZ_LIBRARIES XZ_INCLUDE_DIR)
+FIND_PACKAGE_HANDLE_STANDARD_ARGS(XZ DEFAULT_MSG XZ_LIBRARY XZ_INCLUDE_DIR)
 
-MARK_AS_ADVANCED(XZ_INCLUDE_DIR XZ_LIBRARIES)
+MARK_AS_ADVANCED(XZ_INCLUDE_DIR XZ_LIBRARY)




More information about the sword-cvs mailing list
--- trunk/cmake/FindBZIP2.cmake	2014-03-02 10:29:21 UTC (rev 3048)
+++ trunk/cmake/FindBZIP2.cmake	2014-03-02 11:47:47 UTC (rev 3049)
@@ -3,7 +3,7 @@
 #
 #  BZIP2_FOUND - system has BZIP2
 #  BZIP2_INCLUDE_DIR - the BZIP2 include directory
 #  BZIP2_LIBRARIES - Link these to use BZIP2
 #  BZIP2_DEFINITIONS - Compiler switches required for using BZIP2
 #  BZIP2_NEED_PREFIX - this is set if the functions are prefixed with BZ2_
 
@@ -13,9 +13,9 @@
 # For details see the accompanying COPYING-CMAKE-SCRIPTS file.
 
 
-IF (BZIP2_INCLUDE_DIR AND BZIP2_LIBRARIES)
+IF (BZIP2_INCLUDE_DIR AND BZIP2_LIBRARY)
     SET(BZIP2_FIND_QUIETLY TRUE)
-ENDIF (BZIP2_INCLUDE_DIR AND BZIP2_LIBRARIES)
+ENDIF (BZIP2_INCLUDE_DIR AND BZIP2_LIBRARY)
 
 FIND_PATH(BZIP2_INCLUDE_DIR bzlib.h )
 
@@ -24,11 +24,11 @@
 # handle the QUIETLY and REQUIRED arguments and set BZIP2_FOUND to TRUE if 
 # all listed variables are TRUE
 INCLUDE(FindPackageHandleStandardArgs)
-FIND_PACKAGE_HANDLE_STANDARD_ARGS(BZIP2 DEFAULT_MSG BZIP2_LIBRARIES BZIP2_INCLUDE_DIR)
+FIND_PACKAGE_HANDLE_STANDARD_ARGS(BZIP2 DEFAULT_MSG BZIP2_LIBRARY BZIP2_INCLUDE_DIR)
 
 IF (BZIP2_FOUND)
    INCLUDE(CheckLibraryExists)
-   CHECK_LIBRARY_EXISTS(${BZIP2_LIBRARIES} BZ2_bzBuffToBuffCompress "" BZIP2_NEED_PREFIX)
+   CHECK_LIBRARY_EXISTS(${BZIP2_LIBRARY} BZ2_bzBuffToBuffCompress "" BZIP2_NEED_PREFIX)
 ENDIF (BZIP2_FOUND)
 
-MARK_AS_ADVANCED(BZIP2_INCLUDE_DIR BZIP2_LIBRARIES)
+MARK_AS_ADVANCED(BZIP2_INCLUDE_DIR BZIP2_LIBRARY)
@@ -3,7 +3,7 @@
 #  BZIP2_FOUND - system has BZIP2
 #  BZIP2_INCLUDE_DIR - the BZIP2 include directory
-#  BZIP2_LIBRARIES - Link these to use BZIP2
+#  BZIP2_LIBRARY - Link these to use BZIP2
 #  BZIP2_DEFINITIONS - Compiler switches required for using BZIP2
 #  BZIP2_NEED_PREFIX - this is set if the functions are prefixed with BZ2_

Modified: trunk/cmake/FindXZ.cmake
===================================================================